ewa.rules.FileRule

Package ewa :: Module rules :: Class FileRule |
[hide private]
[frames] | no frames]

# Class FileRule

source code

    object --+
             |
            FileRule

Instance Methods | [hide private]
__init__(self, rulefile, refresh=15, format=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_load_rule(self, mtime=None, lastchecked=None) | source code
_check(self) | source code
__call__(self, filename) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Static Methods | [hide private]
_rules_from_python(pyfile) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, rulefile, refresh=15, format=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)